From ed798e45993797f1e6277e292b70f7701c87cbd9 Mon Sep 17 00:00:00 2001
From: Benedikt Meurer <benny@xfce.org>
Date: Tue, 15 Nov 2005 21:47:31 +0000
Subject: [PATCH] 2005-11-15	Benedikt Meurer <benny@xfce.org>

	* thunar/thunar-gtk-extensions.{c,h}: Add new convenience function
	  thunar_gtk_action_group_create_tool_item(), which creates a new
	  GtkToolItem proxy for a given GtkAction in a GtkActionGroup.
	* thunar/thunar-location-bar.{c,h}, thunar/thunar-location-entry.c,
	  thunar/thunar-location-buttons.c: Add new virtual method
	  thunar_location_bar_is_standalone(), which determines whether a
	  given location bar should be displayed in a standalone fashion, or
	  embedded within a location toolbar.
	* thunar/thunar-window-ui.xml, thunar/thunar-window.c: Check whether
	  the location should be embedded into a location toolbar and if so,
	  generate a toolbar for it on-demand and place it below the menubar.
	  Else, the location bar is placed right above the view pane. This
	  gives a better appearance when using the location entry implementation
	  with a toolbar, and you don't need the toolbar with the pathbar
	  anyways.
	* po/POTFILES.in: Add thunar-preferences-dialog.c here.
	* po/*.po: Merge new strings.




(Old svn revision: 18871)
---
 ChangeLog                        |  20 ++
 po/POTFILES.in                   |   1 +
 po/de.po                         | 169 +++++++++++-----
 po/el.po                         | 318 +++++++++++++++++++------------
 po/es.po                         | 180 ++++++++++++-----
 po/hu.po                         | 180 ++++++++++++-----
 po/ja.po                         | 180 ++++++++++++-----
 thunar/thunar-gtk-extensions.c   |  28 +++
 thunar/thunar-gtk-extensions.h   |   8 +-
 thunar/thunar-location-bar.c     |  20 ++
 thunar/thunar-location-bar.h     |   6 +-
 thunar/thunar-location-buttons.c |   1 +
 thunar/thunar-location-entry.c   |   1 +
 thunar/thunar-window-ui.xml      |   8 +-
 thunar/thunar-window.c           | 134 +++++++++----
 15 files changed, 909 insertions(+), 345 deletions(-)

diff --git a/ChangeLog b/ChangeLog
index 10818b7ba..8e467c03e 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,23 @@
+2005-11-15	Benedikt Meurer <benny@xfce.org>
+
+	* thunar/thunar-gtk-extensions.{c,h}: Add new convenience function
+	  thunar_gtk_action_group_create_tool_item(), which creates a new
+	  GtkToolItem proxy for a given GtkAction in a GtkActionGroup.
+	* thunar/thunar-location-bar.{c,h}, thunar/thunar-location-entry.c,
+	  thunar/thunar-location-buttons.c: Add new virtual method
+	  thunar_location_bar_is_standalone(), which determines whether a
+	  given location bar should be displayed in a standalone fashion, or
+	  embedded within a location toolbar.
+	* thunar/thunar-window-ui.xml, thunar/thunar-window.c: Check whether
+	  the location should be embedded into a location toolbar and if so,
+	  generate a toolbar for it on-demand and place it below the menubar.
+	  Else, the location bar is placed right above the view pane. This
+	  gives a better appearance when using the location entry implementation
+	  with a toolbar, and you don't need the toolbar with the pathbar
+	  anyways.
+	* po/POTFILES.in: Add thunar-preferences-dialog.c here.
+	* po/*.po: Merge new strings.
+
 2005-11-15	Benedikt Meurer <benny@xfce.org>
 
 	* thunar/thunar-standard-view.c: Use "b" as mnemonic for the "Select by
diff --git a/po/POTFILES.in b/po/POTFILES.in
index bfc2dda13..07eaef0a7 100644
--- a/po/POTFILES.in
+++ b/po/POTFILES.in
@@ -59,6 +59,7 @@ thunar/thunar-metafile.c
 thunar/thunar-navigator.c
 thunar/thunar-open-with-action.c
 thunar/thunar-path-entry.c
+thunar/thunar-preferences-dialog.c
 thunar/thunar-preferences.c
 thunar/thunar-progress-dialog.c
 thunar/thunar-properties-dialog.c
diff --git a/po/de.po b/po/de.po
index d10016600..bbbabdc35 100644
--- a/po/de.po
+++ b/po/de.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: Thunar 0.1.2svn\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2005-11-15 19:36+0100\n"
+"POT-Creation-Date: 2005-11-15 22:36+0100\n"
 "PO-Revision-Date: 2005-10-06 22:03+0900\n"
 "Last-Translator: Benedikt Meurer <benny@xfce.org>\n"
 "Language-Team: German <de@li.org>\n"
@@ -250,7 +250,7 @@ msgid "Failed to create symbolic `%s'"
 msgstr ""
 
 #. setup application name
-#: ../thunar/main.c:47 ../thunar/thunar-window.c:351
+#: ../thunar/main.c:47 ../thunar/thunar-window.c:359
 msgid "Thunar"
 msgstr "Thunar"
 
@@ -707,12 +707,12 @@ msgid "Number of visible files"
 msgstr ""
 
 #: ../thunar/thunar-list-model.c:297 ../thunar/thunar-view.c:111
-#: ../thunar/thunar-window.c:222
+#: ../thunar/thunar-window.c:226
 msgid "Show hidden"
 msgstr ""
 
 #: ../thunar/thunar-list-model.c:298 ../thunar/thunar-view.c:112
-#: ../thunar/thunar-window.c:223
+#: ../thunar/thunar-window.c:227
 msgid "Whether to display hidden files"
 msgstr ""
 
@@ -772,7 +772,7 @@ msgstr ""
 msgid "_Location:"
 msgstr ""
 
-#: ../thunar/thunar-navigator.c:137 ../thunar/thunar-window.c:209
+#: ../thunar/thunar-navigator.c:137 ../thunar/thunar-window.c:213
 msgid "Current directory"
 msgstr ""
 
@@ -802,6 +802,65 @@ msgstr ""
 msgid "The icon size for the path entry"
 msgstr ""
 
+#: ../thunar/thunar-preferences-dialog.c:145
+#, fuzzy
+msgid "File Manager Preferences"
+msgstr "Dateimanager"
+
+#: ../thunar/thunar-preferences-dialog.c:161
+msgid "<b>Default View</b>"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:172
+msgid "View _new folders using:"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:177
+msgid "Icon View"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:178
+#, fuzzy
+msgid "Detailed List View"
+msgstr "Detailansicht"
+
+#: ../thunar/thunar-preferences-dialog.c:179
+msgid "Last Active View"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:194
+msgid "Sort _folders before files"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:196
+msgid "Select this option to list folders before files when you sort a folder."
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:200
+msgid "Show hidden and _backup files"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:202
+msgid ""
+"Select this option to show hidden and backup files in new windows. The first "
+"character in a hidden filename is a period (.). The last character in a "
+"backup filename is a tilde (~)."
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:212
+msgid "<b>Icon View</b>"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:223
+msgid "_Text beside icons"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:225
+msgid ""
+"Select this option to place the icon captions for items beside the icon "
+"rather than below the icon."
+msgstr ""
+
 #: ../thunar/thunar-preferences.c:223
 #, c-format
 msgid "Failed to create the Thunar configuration directory in %s"
@@ -1153,7 +1212,7 @@ msgstr ""
 msgid "Text to be displayed in the statusbar associated with this view"
 msgstr ""
 
-#: ../thunar/thunar-view.c:125 ../thunar/thunar-window.c:237
+#: ../thunar/thunar-view.c:125 ../thunar/thunar-window.c:241
 msgid "UI manager"
 msgstr ""
 
@@ -1161,160 +1220,180 @@ msgstr ""
 msgid "UI manager of the surrounding window"
 msgstr ""
 
-#: ../thunar/thunar-window.c:152
+#: ../thunar/thunar-window.c:156
 msgid "_File"
 msgstr "_Datei"
 
-#: ../thunar/thunar-window.c:153
+#: ../thunar/thunar-window.c:157
 msgid "Open New _Window"
 msgstr "_Neues Fenster öffnen"
 
-#: ../thunar/thunar-window.c:153
+#: ../thunar/thunar-window.c:157
 msgid "Open a new Thunar window for the displayed location"
 msgstr ""
 
-#: ../thunar/thunar-window.c:154
+#: ../thunar/thunar-window.c:158
 msgid "Close _All Windows"
 msgstr ""
 
-#: ../thunar/thunar-window.c:154
+#: ../thunar/thunar-window.c:158
 msgid "Close all Thunar windows"
 msgstr "Alle Thunar Fenster schließen"
 
-#: ../thunar/thunar-window.c:155
+#: ../thunar/thunar-window.c:159
 msgid "_Close"
 msgstr "_Schließen"
 
-#: ../thunar/thunar-window.c:155
+#: ../thunar/thunar-window.c:159
 msgid "Close this window"
 msgstr "Dieses Fenster schließen"
 
-#: ../thunar/thunar-window.c:156
+#: ../thunar/thunar-window.c:160
 msgid "_Edit"
 msgstr "_Bearbeiten"
 
-#: ../thunar/thunar-window.c:157
+#: ../thunar/thunar-window.c:161
 #, fuzzy
 msgid "_Preferences"
 msgstr "_Eigenschaften"
 
-#: ../thunar/thunar-window.c:157
+#: ../thunar/thunar-window.c:161
 msgid "Edit Thunar Preferences"
 msgstr ""
 
-#: ../thunar/thunar-window.c:158
+#: ../thunar/thunar-window.c:162
 msgid "_View"
 msgstr "_Anzeige"
 
-#: ../thunar/thunar-window.c:159
-msgid "_Location Bar"
+#: ../thunar/thunar-window.c:163
+msgid "_Location Selector"
 msgstr ""
 
-#: ../thunar/thunar-window.c:160
+#: ../thunar/thunar-window.c:164
 msgid "_Side Pane"
 msgstr ""
 
-#: ../thunar/thunar-window.c:161
+#: ../thunar/thunar-window.c:165
 msgid "_Go"
 msgstr "_Gehe"
 
-#: ../thunar/thunar-window.c:162
+#: ../thunar/thunar-window.c:166
 msgid "Open _Parent"
 msgstr ""
 
-#: ../thunar/thunar-window.c:162
+#: ../thunar/thunar-window.c:166
 msgid "Open the parent folder"
 msgstr ""
 
-#: ../thunar/thunar-window.c:163
+#: ../thunar/thunar-window.c:167
 msgid "_Home"
 msgstr ""
 
-#: ../thunar/thunar-window.c:163
+#: ../thunar/thunar-window.c:167
 msgid "Open the home folder"
 msgstr ""
 
-#: ../thunar/thunar-window.c:164
+#: ../thunar/thunar-window.c:168
 msgid "Open _Location..."
 msgstr ""
 
-#: ../thunar/thunar-window.c:164
+#: ../thunar/thunar-window.c:168
 msgid "Specify a location to open"
 msgstr ""
 
-#: ../thunar/thunar-window.c:165
+#: ../thunar/thunar-window.c:169
 msgid "_Help"
 msgstr "_Hilfe"
 
-#: ../thunar/thunar-window.c:167 ../thunar/thunar-window.c:169
+#: ../thunar/thunar-window.c:171 ../thunar/thunar-window.c:173
 msgid "_About"
 msgstr "Ü_ber"
 
-#: ../thunar/thunar-window.c:167 ../thunar/thunar-window.c:169
+#: ../thunar/thunar-window.c:171 ../thunar/thunar-window.c:173
 msgid "Display information about Thunar"
 msgstr ""
 
-#: ../thunar/thunar-window.c:175
+#: ../thunar/thunar-window.c:179
 msgid "Show _Hidden Files"
 msgstr ""
 
-#: ../thunar/thunar-window.c:175
+#: ../thunar/thunar-window.c:179
 msgid "Toggles the display of hidden files in the current window"
 msgstr ""
 
-#: ../thunar/thunar-window.c:210
+#: ../thunar/thunar-window.c:214
 msgid "The directory currently displayed within this window"
 msgstr ""
 
-#: ../thunar/thunar-window.c:238
+#: ../thunar/thunar-window.c:242
 msgid "The UI manager used within this window"
 msgstr ""
 
 #.
 #. * add the side pane options
 #.
-#: ../thunar/thunar-window.c:293
+#: ../thunar/thunar-window.c:297
 msgid "_Favourites"
 msgstr "Favouriten"
 
-#: ../thunar/thunar-window.c:299 ../thunar/thunar-window.c:320
+#: ../thunar/thunar-window.c:303 ../thunar/thunar-window.c:326
 msgid "_Hidden"
 msgstr ""
 
 #.
-#. * add the location bar options
+#. * add the location selector options
 #.
-#: ../thunar/thunar-window.c:308
-msgid "_Button Style"
+#: ../thunar/thunar-window.c:312
+msgid "_Pathbar Style"
+msgstr ""
+
+#: ../thunar/thunar-window.c:313
+msgid "Modern approach with buttons that correspond to folders"
 msgstr ""
 
-#: ../thunar/thunar-window.c:314
-msgid "_Traditional Style"
+#: ../thunar/thunar-window.c:319
+msgid "_Toolbar Style"
+msgstr ""
+
+#: ../thunar/thunar-window.c:320
+msgid "Traditional approach with location bar and navigation buttons"
+msgstr ""
+
+#: ../thunar/thunar-window.c:326
+msgid "Don't display any location selector"
 msgstr ""
 
 #.
 #. * add view options
 #.
-#: ../thunar/thunar-window.c:329
+#: ../thunar/thunar-window.c:335
 msgid "View as _Icons"
 msgstr ""
 
 #: ../thunar/thunar-window.c:335
+msgid "Display folder content in an icon view"
+msgstr ""
+
+#: ../thunar/thunar-window.c:342
 msgid "View as _Detailed List"
 msgstr ""
 
+#: ../thunar/thunar-window.c:342
+msgid "Display folder content in a detailed list view"
+msgstr ""
+
 #. display an error to the user
-#: ../thunar/thunar-window.c:766
+#: ../thunar/thunar-window.c:836
 msgid "Failed to open home directory"
 msgstr ""
 
-#: ../thunar/thunar-window.c:843
+#: ../thunar/thunar-window.c:911
 msgid ""
 "Thunar is a fast and easy to use file manager\n"
 "for the Xfce Desktop Environment."
 msgstr ""
 
-#: ../thunar/thunar-window.c:848
+#: ../thunar/thunar-window.c:916
 msgid "translator-credits"
 msgstr ""
 
diff --git a/po/el.po b/po/el.po
index 3081b5c9d..7cb9d0859 100644
--- a/po/el.po
+++ b/po/el.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: Thunar 0.1.2svn\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2005-11-15 20:56+0200\n"
+"POT-Creation-Date: 2005-11-15 22:36+0100\n"
 "PO-Revision-Date: 2005-11-15 22:07+0200\n"
 "Last-Translator: Stavros Giannouris <stavrosg2002@freemail.gr>\n"
 "Language-Team: Greek <nls@tux.hellug.gr>\n"
@@ -95,8 +95,7 @@ msgstr "Η διαδρομή είναι υπερβολικά μεγάλη για
 msgid "URI too long to fit into buffer"
 msgstr "Το URI είναι υπερβολικά μεγάλο για να χωρέσει στην προσωρινή μνήμη"
 
-#: ../thunar-vfs/thunar-vfs-thumb.c:144
-#: ../thunar/thunar-details-view.c:150
+#: ../thunar-vfs/thunar-vfs-thumb.c:144 ../thunar/thunar-details-view.c:150
 msgid "Size"
 msgstr "Μέγεθος"
 
@@ -149,8 +148,7 @@ msgstr ""
 msgid "copy of %s"
 msgstr "αντίγραφο του %s"
 
-#: ../thunar-vfs/thunar-vfs-xfer.c:158
-#: ../thunar/thunar-list-model.c:658
+#: ../thunar-vfs/thunar-vfs-xfer.c:158 ../thunar/thunar-list-model.c:658
 #: ../thunar/thunar-properties-dialog.c:588
 #, c-format
 msgid "link to %s"
@@ -177,8 +175,7 @@ msgid "third link to %s"
 msgstr "τρίτος δεσμός προς το %s"
 
 #. if we had no match on the NAMES, try the "%uth copy of %s" pattern
-#: ../thunar-vfs/thunar-vfs-xfer.c:205
-#: ../thunar-vfs/thunar-vfs-xfer.c:221
+#: ../thunar-vfs/thunar-vfs-xfer.c:205 ../thunar-vfs/thunar-vfs-xfer.c:221
 #, c-format
 msgid "%uth copy of %s"
 msgid_plural "%uth copy of %s"
@@ -248,8 +245,7 @@ msgstr "Η δημιουργία συμβολικού δεσμού `%s' απέτ
 msgid "Failed to change mode of `%s'"
 msgstr ""
 
-#: ../thunar-vfs/thunar-vfs-xfer.c:479
-#: ../thunar-vfs/thunar-vfs-xfer.c:539
+#: ../thunar-vfs/thunar-vfs-xfer.c:479 ../thunar-vfs/thunar-vfs-xfer.c:539
 #, c-format
 msgid "Failed to determine file info for `%s'"
 msgstr "Ο προσδιορισμός των πληροφοριών αρχείου για το `%s' απέτυχε"
@@ -265,8 +261,7 @@ msgid "Failed to create symbolic `%s'"
 msgstr "Δεν είναι δυνατή η δημιουργία συμβολικού δεσμού `%s'"
 
 #. setup application name
-#: ../thunar/main.c:47
-#: ../thunar/thunar-window.c:351
+#: ../thunar/main.c:47 ../thunar/thunar-window.c:359
 msgid "Thunar"
 msgstr "Thunar"
 
@@ -295,14 +290,11 @@ msgstr "Διαγραφή αρχείων..."
 msgid "Creating directories..."
 msgstr "Δημιουργία καταλόγων..."
 
-#: ../thunar/thunar-chooser-dialog.c:137
-#: ../thunar/thunar-emblem-chooser.c:115
-#: ../thunar/thunar-emblem-chooser.c:116
-#: ../thunar/thunar-icon-renderer.c:129
+#: ../thunar/thunar-chooser-dialog.c:137 ../thunar/thunar-emblem-chooser.c:115
+#: ../thunar/thunar-emblem-chooser.c:116 ../thunar/thunar-icon-renderer.c:129
 #: ../thunar/thunar-open-with-action.c:115
 #: ../thunar/thunar-open-with-action.c:116
-#: ../thunar/thunar-properties-dialog.c:142
-#: ../thunar/thunar-statusbar.c:190
+#: ../thunar/thunar-properties-dialog.c:142 ../thunar/thunar-statusbar.c:190
 msgid "File"
 msgstr "Αρχείο"
 
@@ -319,8 +311,7 @@ msgid "Whether the chooser should open the specified file"
 msgstr "Εάν ο επιλογέας πρέπει να ανοίγει το συγκεκριμένο αρχείο"
 
 #. the "Open with" action
-#: ../thunar/thunar-chooser-dialog.c:176
-#: ../thunar/thunar-launcher.c:197
+#: ../thunar/thunar-chooser-dialog.c:176 ../thunar/thunar-launcher.c:197
 msgid "Open With"
 msgstr "Άνοιγμα Με"
 
@@ -386,12 +377,9 @@ msgstr ""
 msgid "Shell Scripts"
 msgstr ""
 
-#: ../thunar/thunar-chooser-model.c:116
-#: ../thunar/thunar-folder.c:134
-#: ../thunar/thunar-standard-view.c:371
-#: ../thunar/thunar-statusbar.c:204
-#: ../thunar/thunar-statusbar.c:746
-#: ../thunar/thunar-view.c:82
+#: ../thunar/thunar-chooser-model.c:116 ../thunar/thunar-folder.c:134
+#: ../thunar/thunar-standard-view.c:371 ../thunar/thunar-statusbar.c:204
+#: ../thunar/thunar-statusbar.c:746 ../thunar/thunar-view.c:82
 msgid "Loading"
 msgstr "Φόρτωση"
 
@@ -434,13 +422,11 @@ msgstr "Εάν μπορούν να επικολληθούν τα περιεχό
 msgid "There is nothing on the clipboard to paste"
 msgstr "Δεν υπάρχει τίποτα στο πρόχειρο για να επικολληθεί."
 
-#: ../thunar/thunar-create-dialog.c:100
-#: ../thunar/thunar-create-dialog.c:101
+#: ../thunar/thunar-create-dialog.c:100 ../thunar/thunar-create-dialog.c:101
 msgid "Filename"
 msgstr "Όνομα αρχείου"
 
-#: ../thunar/thunar-create-dialog.c:113
-#: ../thunar/thunar-create-dialog.c:114
+#: ../thunar/thunar-create-dialog.c:113 ../thunar/thunar-create-dialog.c:114
 msgid "Mime Info"
 msgstr "Πληροφορίες Mime"
 
@@ -472,8 +458,7 @@ msgstr "Λεπτομερής απεικόνιση καταλόγων"
 msgid "Details view"
 msgstr "Προβολή λεπτομεριών"
 
-#: ../thunar/thunar-dialogs.c:74
-#: ../thunar/thunar-dialogs.c:78
+#: ../thunar/thunar-dialogs.c:74 ../thunar/thunar-dialogs.c:78
 #, c-format
 msgid "%s."
 msgstr ""
@@ -492,8 +477,7 @@ msgstr "Δ_ημιουργία δεσμού εδώ"
 
 #. display an error to the user
 #. display an error message to the user
-#: ../thunar/thunar-dnd.c:190
-#: ../thunar/thunar-launcher.c:314
+#: ../thunar/thunar-dnd.c:190 ../thunar/thunar-launcher.c:314
 #, c-format
 msgid "Unable to execute file `%s'"
 msgstr "Δεν ήταν δυνατή η εκτέλεση του αρχείου `%s'"
@@ -562,15 +546,12 @@ msgstr ""
 msgid "The file whose icon to render"
 msgstr "Το αρχείο του οποίου το εικονίδιο να προβληθει"
 
-#: ../thunar/thunar-icon-renderer.c:145
-#: ../thunar/thunar-icon-renderer.c:146
-#: ../thunar/thunar-text-renderer.c:172
-#: ../thunar/thunar-text-renderer.c:173
+#: ../thunar/thunar-icon-renderer.c:145 ../thunar/thunar-icon-renderer.c:146
+#: ../thunar/thunar-text-renderer.c:172 ../thunar/thunar-text-renderer.c:173
 msgid "Follow state"
 msgstr "Παρακολούθηση κατάστασης"
 
-#: ../thunar/thunar-icon-renderer.c:158
-#: ../thunar/thunar-path-entry.c:179
+#: ../thunar/thunar-icon-renderer.c:158 ../thunar/thunar-path-entry.c:179
 msgid "Icon size"
 msgstr "Μέγεθος εικονιδίου"
 
@@ -630,8 +611,7 @@ msgstr "_Φθίνουσα"
 msgid "Sort items in descending order"
 msgstr "Ταξινόμηση καρτελών με φθίνουσα σειρά"
 
-#: ../thunar/thunar-icon-view.c:181
-#: ../thunar/thunar-icon-view.c:182
+#: ../thunar/thunar-icon-view.c:181 ../thunar/thunar-icon-view.c:182
 msgid "Text beside icons"
 msgstr ""
 
@@ -643,24 +623,20 @@ msgstr ""
 msgid "Icon view"
 msgstr "Προβολή Εικονιδίων"
 
-#: ../thunar/thunar-launcher.c:134
-#: ../thunar/thunar-launcher.c:135
+#: ../thunar/thunar-launcher.c:134 ../thunar/thunar-launcher.c:135
 msgid "Action group"
 msgstr "Ομάδα ενέργειας"
 
-#: ../thunar/thunar-launcher.c:147
-#: ../thunar/thunar-launcher.c:148
+#: ../thunar/thunar-launcher.c:147 ../thunar/thunar-launcher.c:148
 msgid "Selected files"
 msgstr "Επιλεγμένα αρχεία"
 
-#: ../thunar/thunar-launcher.c:160
-#: ../thunar/thunar-launcher.c:161
+#: ../thunar/thunar-launcher.c:160 ../thunar/thunar-launcher.c:161
 msgid "Widget"
 msgstr "Μαραφέτι"
 
 #. the "Open" action
-#: ../thunar/thunar-launcher.c:189
-#: ../thunar/thunar-launcher.c:521
+#: ../thunar/thunar-launcher.c:189 ../thunar/thunar-launcher.c:521
 #: ../thunar/thunar-launcher.c:539
 msgid "_Open"
 msgstr "_Άνοιγμα"
@@ -736,20 +712,17 @@ msgstr "Αριθμός Αρχείων"
 msgid "Number of visible files"
 msgstr "Αριθμός ορατών αρχείων"
 
-#: ../thunar/thunar-list-model.c:297
-#: ../thunar/thunar-view.c:111
-#: ../thunar/thunar-window.c:222
+#: ../thunar/thunar-list-model.c:297 ../thunar/thunar-view.c:111
+#: ../thunar/thunar-window.c:226
 msgid "Show hidden"
 msgstr "Προβολή κρυφών"
 
-#: ../thunar/thunar-list-model.c:298
-#: ../thunar/thunar-view.c:112
-#: ../thunar/thunar-window.c:223
+#: ../thunar/thunar-list-model.c:298 ../thunar/thunar-view.c:112
+#: ../thunar/thunar-window.c:227
 msgid "Whether to display hidden files"
 msgstr "Αν θα προβάλλονται τα κρυφά αρχεία"
 
-#: ../thunar/thunar-list-model.c:656
-#: ../thunar/thunar-properties-dialog.c:586
+#: ../thunar/thunar-list-model.c:656 ../thunar/thunar-properties-dialog.c:586
 msgid "broken link"
 msgstr "σπασμένος δεσμός"
 
@@ -782,8 +755,7 @@ msgstr "\"%s\" (%s) δεσμός προς το %s"
 msgid "\"%s\" (%s) %s"
 msgstr "\"%s\" (%s) %s"
 
-#: ../thunar/thunar-list-model.c:1971
-#: ../thunar/thunar-list-model.c:1976
+#: ../thunar/thunar-list-model.c:1971 ../thunar/thunar-list-model.c:1976
 #, c-format
 msgid "%d item selected"
 msgid_plural "%d items selected (%s)"
@@ -806,8 +778,7 @@ msgstr "Άνοιγμα Τοποθεσίας"
 msgid "_Location:"
 msgstr "_Τοποθεσία:"
 
-#: ../thunar/thunar-navigator.c:137
-#: ../thunar/thunar-window.c:209
+#: ../thunar/thunar-navigator.c:137 ../thunar/thunar-window.c:213
 msgid "Current directory"
 msgstr "Τρέχον κατάλογος"
 
@@ -837,6 +808,68 @@ msgstr "Το αρχείο που εμφανίζεται τώρα"
 msgid "The icon size for the path entry"
 msgstr "Μέγεθος εικονιδίου για τη διαδρομή"
 
+#: ../thunar/thunar-preferences-dialog.c:145
+#, fuzzy
+msgid "File Manager Preferences"
+msgstr "Επεξεργασία Προτιμήσεων Thunar"
+
+#: ../thunar/thunar-preferences-dialog.c:161
+msgid "<b>Default View</b>"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:172
+msgid "View _new folders using:"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:177
+#, fuzzy
+msgid "Icon View"
+msgstr "Προβολή Εικονιδίων"
+
+#: ../thunar/thunar-preferences-dialog.c:178
+#, fuzzy
+msgid "Detailed List View"
+msgstr "Προβολή λεπτομεριών"
+
+#: ../thunar/thunar-preferences-dialog.c:179
+msgid "Last Active View"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:194
+msgid "Sort _folders before files"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:196
+msgid "Select this option to list folders before files when you sort a folder."
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:200
+#, fuzzy
+msgid "Show hidden and _backup files"
+msgstr "Εμφάνιση _Κρυφών Αρχείων"
+
+#: ../thunar/thunar-preferences-dialog.c:202
+msgid ""
+"Select this option to show hidden and backup files in new windows. The first "
+"character in a hidden filename is a period (.). The last character in a "
+"backup filename is a tilde (~)."
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:212
+#, fuzzy
+msgid "<b>Icon View</b>"
+msgstr "Προβολή Εικονιδίων"
+
+#: ../thunar/thunar-preferences-dialog.c:223
+msgid "_Text beside icons"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:225
+msgid ""
+"Select this option to place the icon captions for items beside the icon "
+"rather than below the icon."
+msgstr ""
+
 #: ../thunar/thunar-preferences.c:223
 #, c-format
 msgid "Failed to create the Thunar configuration directory in %s"
@@ -1037,8 +1070,7 @@ msgstr "Επιλογή _βάσει μοτίβου"
 msgid "Select all files that match a certain pattern"
 msgstr "Επιλογή όλων των αρχείων που ταιριάζουν σε ένα μοτίβο"
 
-#: ../thunar/thunar-standard-view.c:267
-#: ../thunar/thunar-standard-view.c:2471
+#: ../thunar/thunar-standard-view.c:267 ../thunar/thunar-standard-view.c:2471
 msgid "Du_plicate File"
 msgid_plural "Du_plicate Files"
 msgstr[0] ""
@@ -1048,8 +1080,7 @@ msgstr[1] ""
 msgid "Duplicate each selected file"
 msgstr ""
 
-#: ../thunar/thunar-standard-view.c:268
-#: ../thunar/thunar-standard-view.c:2477
+#: ../thunar/thunar-standard-view.c:268 ../thunar/thunar-standard-view.c:2477
 msgid "Ma_ke Link"
 msgid_plural "Ma_ke Links"
 msgstr[0] "Δημιουργία _Δεσμού"
@@ -1067,8 +1098,7 @@ msgstr "_Μετονομασία"
 msgid "Rename the selected file"
 msgstr "Μετονομασία του επιλεγμένου αρχείου"
 
-#: ../thunar/thunar-standard-view.c:372
-#: ../thunar/thunar-view.c:83
+#: ../thunar/thunar-standard-view.c:372 ../thunar/thunar-view.c:83
 msgid "Whether the view is currently being loaded"
 msgstr "Εάν είναι φορτωμένη η προβολή"
 
@@ -1088,7 +1118,9 @@ msgstr "Νέος Φάκελος..."
 #: ../thunar/thunar-standard-view.c:1379
 #, c-format
 msgid "Cannot convert filename `%s' to the local encoding"
-msgstr "Δεν είναι δυνατή η μετατροπή του ονόματος αρχείου `%s' στην τοπική κωδικοποίηση"
+msgstr ""
+"Δεν είναι δυνατή η μετατροπή του ονόματος αρχείου `%s' στην τοπική "
+"κωδικοποίηση"
 
 #: ../thunar/thunar-standard-view.c:1525
 #, c-format
@@ -1153,13 +1185,11 @@ msgstr[1] "_Διαγραφή Αρχείων"
 msgid "The file whose icon to display"
 msgstr "Το αρχείο του οποίου το εικονίδιο να προβληθει"
 
-#: ../thunar/thunar-statusbar.c:205
-#: ../thunar/thunar-statusbar.c:747
+#: ../thunar/thunar-statusbar.c:205 ../thunar/thunar-statusbar.c:747
 msgid "Whether to display a loading animation"
 msgstr "Αν θα εμφανίζεται γραφικό φόρτωσης"
 
-#: ../thunar/thunar-statusbar.c:760
-#: ../thunar/thunar-view.c:98
+#: ../thunar/thunar-statusbar.c:760 ../thunar/thunar-view.c:98
 msgid "Statusbar text"
 msgstr "Κείμενο μπάρας κατάστασης"
 
@@ -1195,8 +1225,7 @@ msgstr "Το πλάτος αναδίπλωσης"
 msgid "Text to be displayed in the statusbar associated with this view"
 msgstr "Κείμενο που θα εμφανίζεται στην γραμμή κατάστασης σε αυτή την προβολή"
 
-#: ../thunar/thunar-view.c:125
-#: ../thunar/thunar-window.c:237
+#: ../thunar/thunar-view.c:125 ../thunar/thunar-window.c:241
 msgid "UI manager"
 msgstr "Διαχειριστής UI"
 
@@ -1204,156 +1233,177 @@ msgstr "Διαχειριστής UI"
 msgid "UI manager of the surrounding window"
 msgstr ""
 
-#: ../thunar/thunar-window.c:152
+#: ../thunar/thunar-window.c:156
 msgid "_File"
 msgstr "_Αρχείο"
 
-#: ../thunar/thunar-window.c:153
+#: ../thunar/thunar-window.c:157
 msgid "Open New _Window"
 msgstr "Άνοιγμα νέου _παραθύρου"
 
-#: ../thunar/thunar-window.c:153
+#: ../thunar/thunar-window.c:157
 msgid "Open a new Thunar window for the displayed location"
-msgstr "'Ανοιγμα ενός άλλου παράθυρου του Thunar για την προβαλλόμενη τοποθεσία"
+msgstr ""
+"'Ανοιγμα ενός άλλου παράθυρου του Thunar για την προβαλλόμενη τοποθεσία"
 
-#: ../thunar/thunar-window.c:154
+#: ../thunar/thunar-window.c:158
 msgid "Close _All Windows"
 msgstr "Κλείσιμο _Όλων των Παραθύρων"
 
-#: ../thunar/thunar-window.c:154
+#: ../thunar/thunar-window.c:158
 msgid "Close all Thunar windows"
 msgstr "Κλείσιμο όλων των παραθύρων του Thunar"
 
-#: ../thunar/thunar-window.c:155
+#: ../thunar/thunar-window.c:159
 msgid "_Close"
 msgstr "_Κλείσιμο"
 
-#: ../thunar/thunar-window.c:155
+#: ../thunar/thunar-window.c:159
 msgid "Close this window"
 msgstr "Κλείσιμο αυτού του παραθύρου"
 
-#: ../thunar/thunar-window.c:156
+#: ../thunar/thunar-window.c:160
 msgid "_Edit"
 msgstr "_Επεξεργασία"
 
-#: ../thunar/thunar-window.c:157
+#: ../thunar/thunar-window.c:161
 msgid "_Preferences"
 msgstr "_Προτιμήσεις"
 
-#: ../thunar/thunar-window.c:157
+#: ../thunar/thunar-window.c:161
 msgid "Edit Thunar Preferences"
 msgstr "Επεξεργασία Προτιμήσεων Thunar"
 
-#: ../thunar/thunar-window.c:158
+#: ../thunar/thunar-window.c:162
 msgid "_View"
 msgstr "_Προβολή"
 
-#: ../thunar/thunar-window.c:159
-msgid "_Location Bar"
+#: ../thunar/thunar-window.c:163
+#, fuzzy
+msgid "_Location Selector"
 msgstr "Γραμμή _Τοποθεσίας"
 
-#: ../thunar/thunar-window.c:160
+#: ../thunar/thunar-window.c:164
 msgid "_Side Pane"
 msgstr "_Πλευρικό Ταμπλό"
 
-#: ../thunar/thunar-window.c:161
+#: ../thunar/thunar-window.c:165
 msgid "_Go"
 msgstr "_Μετάβαση"
 
-#: ../thunar/thunar-window.c:162
+#: ../thunar/thunar-window.c:166
 msgid "Open _Parent"
 msgstr "Άνοιγμα _Γονικού"
 
-#: ../thunar/thunar-window.c:162
+#: ../thunar/thunar-window.c:166
 msgid "Open the parent folder"
 msgstr "Άνοιγμα του γονικού φακέλου"
 
-#: ../thunar/thunar-window.c:163
+#: ../thunar/thunar-window.c:167
 msgid "_Home"
 msgstr "_Αρχή"
 
-#: ../thunar/thunar-window.c:163
+#: ../thunar/thunar-window.c:167
 msgid "Open the home folder"
 msgstr "Άνοιγμα του αρχικού φακέλου"
 
-#: ../thunar/thunar-window.c:164
+#: ../thunar/thunar-window.c:168
 msgid "Open _Location..."
 msgstr "Άνοιγμα _Τοποθεσίας..."
 
-#: ../thunar/thunar-window.c:164
+#: ../thunar/thunar-window.c:168
 msgid "Specify a location to open"
 msgstr "Καθορίστε μια τοποθεσία για άνοιγμα"
 
-#: ../thunar/thunar-window.c:165
+#: ../thunar/thunar-window.c:169
 msgid "_Help"
 msgstr "_Βοήθεια"
 
-#: ../thunar/thunar-window.c:167
-#: ../thunar/thunar-window.c:169
+#: ../thunar/thunar-window.c:171 ../thunar/thunar-window.c:173
 msgid "_About"
 msgstr "_Περί"
 
-#: ../thunar/thunar-window.c:167
-#: ../thunar/thunar-window.c:169
+#: ../thunar/thunar-window.c:171 ../thunar/thunar-window.c:173
 msgid "Display information about Thunar"
 msgstr "Εμφάνιση πληροφοριών σχετικά με το Thunar"
 
-#: ../thunar/thunar-window.c:175
+#: ../thunar/thunar-window.c:179
 msgid "Show _Hidden Files"
 msgstr "Εμφάνιση _Κρυφών Αρχείων"
 
-#: ../thunar/thunar-window.c:175
+#: ../thunar/thunar-window.c:179
 msgid "Toggles the display of hidden files in the current window"
 msgstr "Εναλλάσσει την εμφάνιση κρυφών αρχείων στο τρέχον παράθυρο"
 
-#: ../thunar/thunar-window.c:210
+#: ../thunar/thunar-window.c:214
 msgid "The directory currently displayed within this window"
 msgstr "Ο κατάλογος που εμφανίζεται τώρα σε αυτό το παράθυρο"
 
-#: ../thunar/thunar-window.c:238
+#: ../thunar/thunar-window.c:242
 msgid "The UI manager used within this window"
 msgstr ""
 
 #.
 #. * add the side pane options
 #.
-#: ../thunar/thunar-window.c:293
+#: ../thunar/thunar-window.c:297
 msgid "_Favourites"
 msgstr "_Αγαπημένα"
 
-#: ../thunar/thunar-window.c:299
-#: ../thunar/thunar-window.c:320
+#: ../thunar/thunar-window.c:303 ../thunar/thunar-window.c:326
 msgid "_Hidden"
 msgstr "Κ_ρυφό"
 
 #.
-#. * add the location bar options
+#. * add the location selector options
 #.
-#: ../thunar/thunar-window.c:308
-msgid "_Button Style"
-msgstr "_Στυλ κουμπιών"
+#: ../thunar/thunar-window.c:312
+#, fuzzy
+msgid "_Pathbar Style"
+msgstr "_Παραδοσιακό Στυλ"
+
+#: ../thunar/thunar-window.c:313
+msgid "Modern approach with buttons that correspond to folders"
+msgstr ""
 
-#: ../thunar/thunar-window.c:314
-msgid "_Traditional Style"
+#: ../thunar/thunar-window.c:319
+#, fuzzy
+msgid "_Toolbar Style"
 msgstr "_Παραδοσιακό Στυλ"
 
+#: ../thunar/thunar-window.c:320
+msgid "Traditional approach with location bar and navigation buttons"
+msgstr ""
+
+#: ../thunar/thunar-window.c:326
+msgid "Don't display any location selector"
+msgstr ""
+
 #.
 #. * add view options
 #.
-#: ../thunar/thunar-window.c:329
+#: ../thunar/thunar-window.c:335
 msgid "View as _Icons"
 msgstr "Προβολή Ε_ικονιδίων"
 
 #: ../thunar/thunar-window.c:335
+msgid "Display folder content in an icon view"
+msgstr ""
+
+#: ../thunar/thunar-window.c:342
 msgid "View as _Detailed List"
 msgstr "Προβολή _Λεπτομερούς Λίστας"
 
+#: ../thunar/thunar-window.c:342
+msgid "Display folder content in a detailed list view"
+msgstr ""
+
 #. display an error to the user
-#: ../thunar/thunar-window.c:766
+#: ../thunar/thunar-window.c:836
 msgid "Failed to open home directory"
 msgstr "Αδυναμία ανοίγματος αρχικού καταλόγου"
 
-#: ../thunar/thunar-window.c:843
+#: ../thunar/thunar-window.c:911
 msgid ""
 "Thunar is a fast and easy to use file manager\n"
 "for the Xfce Desktop Environment."
@@ -1361,7 +1411,7 @@ msgstr ""
 "Ο Thunar είναι ένας γρήγορος και εύκολος διαχειριστής αρχείων\n"
 "για το Περιβάλλον Εργασίας Xfce."
 
-#: ../thunar/thunar-window.c:848
+#: ../thunar/thunar-window.c:916
 msgid "translator-credits"
 msgstr "Σταύρος Γιαννούρης <stavrosg2002@freemail.gr>"
 
@@ -1379,7 +1429,8 @@ msgstr "Γραφικό συστατικό ετικέτας"
 
 #: ../thunarx/thunarx-property-page.c:118
 msgid "A widget to display in place of the usual page label"
-msgstr "Ένα γραφικό συστατικό που θα εμφανίζεται στην θέση της συνήθους ετικέτας"
+msgstr ""
+"Ένα γραφικό συστατικό που θα εμφανίζεται στην θέση της συνήθους ετικέτας"
 
 #: ../Thunar.desktop.in.h:1
 msgid "Browse the filesystem with the file manager"
@@ -1393,62 +1444,89 @@ msgstr "Διαχειριστής Αρχείων"
 msgid "Thunar File Manager"
 msgstr "Διαχειριστής Αρχείων Thunar"
 
+#~ msgid "_Button Style"
+#~ msgstr "_Στυλ κουμπιών"
+
 #~ msgid "The application \"%s\" supports only local documents."
 #~ msgstr "Η εφαρμογή \"%s\" υποστηρίζει μόνο τοπικά έγγραφα."
+
 #~ msgid ""
 #~ "Unable to query information about\n"
 #~ "the file %s."
 #~ msgstr ""
 #~ "Δεν ήταν δυνατή η λήψη πληροφοριών\n"
 #~ "για το αρχείο %s."
+
 #~ msgid "Unable to open file %s."
 #~ msgstr "Αδύνατο το άνοιγμα αρχείου %s."
+
 #~ msgid "Files"
 #~ msgstr "Αρχεία"
+
 #~ msgid "The list of files stored within this trash"
 #~ msgstr "Η λίστα με τα αρχεία που βρίσκονται σε αυτό τον κάδο"
+
 #~ msgid "Empty"
 #~ msgstr "Άδειο"
+
 #~ msgid "Whether all trashes are empty"
 #~ msgstr "Εάν είναι άδειοι όλοι οι κάδοι"
+
 #~ msgid "The URI '%s' is invalid"
 #~ msgstr "Το URI '%s' δεν είναι έγκυρο"
+
 #~ msgid "The trash file URI '%s' may not include a '#'"
 #~ msgstr "Το URI του αρχείου κάδου '%s'  μπορεί να μην περιέχει ένα '#'"
+
 #~ msgid "Only local directories can be listed"
 #~ msgstr "Προβολή μόνο τοπικών καταλόγων"
+
 #~ msgid "Computer"
 #~ msgstr "Υπολογιστής"
+
 #~ msgid "Model"
 #~ msgstr "Μοντέλο"
+
 #~ msgid "The model to display"
 #~ msgstr "Ποιο μοντέλο θα απεικονιστεί"
+
 #~ msgid "File column"
 #~ msgstr "Στήλη αρχείου"
+
 #~ msgid "The column which contains the file"
 #~ msgstr "Η στήλη που περιέχει το αρχείο"
+
 #~ msgid "Position column"
 #~ msgstr "Στήλη τοποθέτησης"
+
 #~ msgid "The column which contains the position"
 #~ msgstr "Η στήλη που περιέχει τη θέση"
+
 #~ msgid "Unable to rename file"
 #~ msgstr "Αδυναμία μετονομασίας του αρχείου"
+
 #~ msgid "unknown"
 #~ msgstr "άγνωστο"
+
 #~ msgid "\"%s\" %s"
 #~ msgstr "\"%s\" %s"
+
 #~ msgid "Select by _pattern"
 #~ msgstr "Επιλογή βάσει _μοτίβου"
+
 #~ msgid "Trash"
 #~ msgstr "Απορρίμματα"
+
 #~ msgid "_Empty Trash Bin"
 #~ msgstr "_Άδειασμα Απορριμμάτων"
+
 #~ msgid "Delete all items in the Trash"
 #~ msgstr "Διαγραφή όλων των αντικειμένων από τα Απορρίμματα"
+
 #~ msgid "This will delete %d file currently located in the trash bin."
 #~ msgid_plural "This will delete %d files currently located in the trash bin."
 #~ msgstr[0] "Αυτό θα διαγράψει %d αρχείο που βρίσκεται τώρα στα απορρίμματα."
 #~ msgstr[1] "Αυτό θα διαγράψει %d αρχεία που βρίσκονται τώρα στα απορρίμματα."
+
 #~ msgid "Other..."
 #~ msgstr "Άλλο..."
-
diff --git a/po/es.po b/po/es.po
index 66331a46a..05a2d8e97 100644
--- a/po/es.po
+++ b/po/es.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: Thunar 0.1.2svn\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2005-11-15 19:36+0100\n"
+"POT-Creation-Date: 2005-11-15 22:36+0100\n"
 "PO-Revision-Date: 2005-10-14 23:57+0900\n"
 "Last-Translator: Pablo Hernández-M. Saiz <homeless3d@gmail.com>\n"
 "Language-Team: Spanish <es@li.org>\n"
@@ -260,7 +260,7 @@ msgid "Failed to create symbolic `%s'"
 msgstr "Imposible crear el enlace de %s."
 
 #. setup application name
-#: ../thunar/main.c:47 ../thunar/thunar-window.c:351
+#: ../thunar/main.c:47 ../thunar/thunar-window.c:359
 msgid "Thunar"
 msgstr "Thunar"
 
@@ -724,12 +724,12 @@ msgid "Number of visible files"
 msgstr "Número de archivos visibles"
 
 #: ../thunar/thunar-list-model.c:297 ../thunar/thunar-view.c:111
-#: ../thunar/thunar-window.c:222
+#: ../thunar/thunar-window.c:226
 msgid "Show hidden"
 msgstr "Mostrar ocultos"
 
 #: ../thunar/thunar-list-model.c:298 ../thunar/thunar-view.c:112
-#: ../thunar/thunar-window.c:223
+#: ../thunar/thunar-window.c:227
 msgid "Whether to display hidden files"
 msgstr ""
 
@@ -789,7 +789,7 @@ msgstr "Abrir dirección..."
 msgid "_Location:"
 msgstr "_Dirección"
 
-#: ../thunar/thunar-navigator.c:137 ../thunar/thunar-window.c:209
+#: ../thunar/thunar-navigator.c:137 ../thunar/thunar-window.c:213
 msgid "Current directory"
 msgstr "Directorio actual"
 
@@ -819,6 +819,68 @@ msgstr ""
 msgid "The icon size for the path entry"
 msgstr ""
 
+#: ../thunar/thunar-preferences-dialog.c:145
+#, fuzzy
+msgid "File Manager Preferences"
+msgstr "Gestor de archivos"
+
+#: ../thunar/thunar-preferences-dialog.c:161
+msgid "<b>Default View</b>"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:172
+msgid "View _new folders using:"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:177
+#, fuzzy
+msgid "Icon View"
+msgstr "Vista de iconos"
+
+#: ../thunar/thunar-preferences-dialog.c:178
+#, fuzzy
+msgid "Detailed List View"
+msgstr "Vista detallada"
+
+#: ../thunar/thunar-preferences-dialog.c:179
+msgid "Last Active View"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:194
+msgid "Sort _folders before files"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:196
+msgid "Select this option to list folders before files when you sort a folder."
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:200
+#, fuzzy
+msgid "Show hidden and _backup files"
+msgstr "Mostrar los archivos _ocultos"
+
+#: ../thunar/thunar-preferences-dialog.c:202
+msgid ""
+"Select this option to show hidden and backup files in new windows. The first "
+"character in a hidden filename is a period (.). The last character in a "
+"backup filename is a tilde (~)."
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:212
+#, fuzzy
+msgid "<b>Icon View</b>"
+msgstr "Vista de iconos"
+
+#: ../thunar/thunar-preferences-dialog.c:223
+msgid "_Text beside icons"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:225
+msgid ""
+"Select this option to place the icon captions for items beside the icon "
+"rather than below the icon."
+msgstr ""
+
 #: ../thunar/thunar-preferences.c:223
 #, fuzzy, c-format
 msgid "Failed to create the Thunar configuration directory in %s"
@@ -1187,7 +1249,7 @@ msgstr ""
 msgid "Text to be displayed in the statusbar associated with this view"
 msgstr ""
 
-#: ../thunar/thunar-view.c:125 ../thunar/thunar-window.c:237
+#: ../thunar/thunar-view.c:125 ../thunar/thunar-window.c:241
 msgid "UI manager"
 msgstr ""
 
@@ -1195,159 +1257,182 @@ msgstr ""
 msgid "UI manager of the surrounding window"
 msgstr ""
 
-#: ../thunar/thunar-window.c:152
+#: ../thunar/thunar-window.c:156
 msgid "_File"
 msgstr "_Archivo"
 
-#: ../thunar/thunar-window.c:153
+#: ../thunar/thunar-window.c:157
 msgid "Open New _Window"
 msgstr "Nueva _ventana"
 
-#: ../thunar/thunar-window.c:153
+#: ../thunar/thunar-window.c:157
 msgid "Open a new Thunar window for the displayed location"
 msgstr ""
 
-#: ../thunar/thunar-window.c:154
+#: ../thunar/thunar-window.c:158
 msgid "Close _All Windows"
 msgstr "Cerrar _todas las ventanas"
 
-#: ../thunar/thunar-window.c:154
+#: ../thunar/thunar-window.c:158
 msgid "Close all Thunar windows"
 msgstr "Cerrar todas las ventanas de Thunar"
 
-#: ../thunar/thunar-window.c:155
+#: ../thunar/thunar-window.c:159
 msgid "_Close"
 msgstr "_Cerrar"
 
-#: ../thunar/thunar-window.c:155
+#: ../thunar/thunar-window.c:159
 msgid "Close this window"
 msgstr "Cerrar esta ventana"
 
-#: ../thunar/thunar-window.c:156
+#: ../thunar/thunar-window.c:160
 msgid "_Edit"
 msgstr "_Editar"
 
-#: ../thunar/thunar-window.c:157
+#: ../thunar/thunar-window.c:161
 #, fuzzy
 msgid "_Preferences"
 msgstr "_Propiedades"
 
-#: ../thunar/thunar-window.c:157
+#: ../thunar/thunar-window.c:161
 msgid "Edit Thunar Preferences"
 msgstr ""
 
-#: ../thunar/thunar-window.c:158
+#: ../thunar/thunar-window.c:162
 msgid "_View"
 msgstr "_Ver"
 
-#: ../thunar/thunar-window.c:159
-msgid "_Location Bar"
+#: ../thunar/thunar-window.c:163
+#, fuzzy
+msgid "_Location Selector"
 msgstr "Barra de _dirección"
 
-#: ../thunar/thunar-window.c:160
+#: ../thunar/thunar-window.c:164
 msgid "_Side Pane"
 msgstr "Panel _lateral"
 
-#: ../thunar/thunar-window.c:161
+#: ../thunar/thunar-window.c:165
 msgid "_Go"
 msgstr "_Ir a"
 
-#: ../thunar/thunar-window.c:162
+#: ../thunar/thunar-window.c:166
 msgid "Open _Parent"
 msgstr "Abrir _antecesor"
 
-#: ../thunar/thunar-window.c:162
+#: ../thunar/thunar-window.c:166
 msgid "Open the parent folder"
 msgstr "Abre la carpeta anterior"
 
 # msgstr "Sistema de archivos"
-#: ../thunar/thunar-window.c:163
+#: ../thunar/thunar-window.c:167
 #, fuzzy
 msgid "_Home"
 msgstr "Casa"
 
-#: ../thunar/thunar-window.c:163
+#: ../thunar/thunar-window.c:167
 #, fuzzy
 msgid "Open the home folder"
 msgstr "Abre la carpeta anterior"
 
-#: ../thunar/thunar-window.c:164
+#: ../thunar/thunar-window.c:168
 msgid "Open _Location..."
 msgstr "Abrir _dirección..."
 
-#: ../thunar/thunar-window.c:164
+#: ../thunar/thunar-window.c:168
 msgid "Specify a location to open"
 msgstr "Especificar una dirección para abrir"
 
-#: ../thunar/thunar-window.c:165
+#: ../thunar/thunar-window.c:169
 msgid "_Help"
 msgstr "A_yuda"
 
-#: ../thunar/thunar-window.c:167 ../thunar/thunar-window.c:169
+#: ../thunar/thunar-window.c:171 ../thunar/thunar-window.c:173
 msgid "_About"
 msgstr "_Acerca de"
 
-#: ../thunar/thunar-window.c:167 ../thunar/thunar-window.c:169
+#: ../thunar/thunar-window.c:171 ../thunar/thunar-window.c:173
 msgid "Display information about Thunar"
 msgstr "Muestra información acerca de Thunar"
 
-#: ../thunar/thunar-window.c:175
+#: ../thunar/thunar-window.c:179
 #, fuzzy
 msgid "Show _Hidden Files"
 msgstr "Mostrar los archivos _ocultos"
 
-#: ../thunar/thunar-window.c:175
+#: ../thunar/thunar-window.c:179
 msgid "Toggles the display of hidden files in the current window"
 msgstr ""
 
-#: ../thunar/thunar-window.c:210
+#: ../thunar/thunar-window.c:214
 msgid "The directory currently displayed within this window"
 msgstr ""
 
-#: ../thunar/thunar-window.c:238
+#: ../thunar/thunar-window.c:242
 msgid "The UI manager used within this window"
 msgstr ""
 
 #.
 #. * add the side pane options
 #.
-#: ../thunar/thunar-window.c:293
+#: ../thunar/thunar-window.c:297
 msgid "_Favourites"
 msgstr "_Marcadores"
 
-#: ../thunar/thunar-window.c:299 ../thunar/thunar-window.c:320
+#: ../thunar/thunar-window.c:303 ../thunar/thunar-window.c:326
 msgid "_Hidden"
 msgstr "_Oculto/a"
 
 #.
-#. * add the location bar options
+#. * add the location selector options
 #.
-#: ../thunar/thunar-window.c:308
-msgid "_Button Style"
-msgstr "Estilo _botón"
+#: ../thunar/thunar-window.c:312
+#, fuzzy
+msgid "_Pathbar Style"
+msgstr "Estilo _tradicional"
+
+#: ../thunar/thunar-window.c:313
+msgid "Modern approach with buttons that correspond to folders"
+msgstr ""
 
-#: ../thunar/thunar-window.c:314
-msgid "_Traditional Style"
+#: ../thunar/thunar-window.c:319
+#, fuzzy
+msgid "_Toolbar Style"
 msgstr "Estilo _tradicional"
 
+#: ../thunar/thunar-window.c:320
+msgid "Traditional approach with location bar and navigation buttons"
+msgstr ""
+
+#: ../thunar/thunar-window.c:326
+msgid "Don't display any location selector"
+msgstr ""
+
 #.
 #. * add view options
 #.
-#: ../thunar/thunar-window.c:329
+#: ../thunar/thunar-window.c:335
 msgid "View as _Icons"
 msgstr "Ver como _Iconos"
 
 #: ../thunar/thunar-window.c:335
+msgid "Display folder content in an icon view"
+msgstr ""
+
+#: ../thunar/thunar-window.c:342
 msgid "View as _Detailed List"
 msgstr "Ver como _Lista"
 
+#: ../thunar/thunar-window.c:342
+msgid "Display folder content in a detailed list view"
+msgstr ""
+
 #. display an error to the user
-#: ../thunar/thunar-window.c:766
+#: ../thunar/thunar-window.c:836
 #, fuzzy
 msgid "Failed to open home directory"
 msgstr "Imposible abrir el directorio %s."
 
-#: ../thunar/thunar-window.c:843
+#: ../thunar/thunar-window.c:911
 msgid ""
 "Thunar is a fast and easy to use file manager\n"
 "for the Xfce Desktop Environment."
@@ -1355,7 +1440,7 @@ msgstr ""
 "Thunar es un gestor de archivos rápido\n"
 "y fácil de usar para el escritorio Xfce"
 
-#: ../thunar/thunar-window.c:848
+#: ../thunar/thunar-window.c:916
 msgid "translator-credits"
 msgstr ""
 
@@ -1387,6 +1472,9 @@ msgstr "Gestor de archivos"
 msgid "Thunar File Manager"
 msgstr "Gestor de archivos Thunar"
 
+#~ msgid "_Button Style"
+#~ msgstr "Estilo _botón"
+
 #, fuzzy
 #~ msgid "Select by _Pattern"
 #~ msgstr "Seleccionar por _patrón"
diff --git a/po/hu.po b/po/hu.po
index e96a35794..9e546dd3d 100644
--- a/po/hu.po
+++ b/po/hu.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: Thunar 0.1.2svn\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2005-11-15 19:36+0100\n"
+"POT-Creation-Date: 2005-11-15 22:36+0100\n"
 "PO-Revision-Date: 2005-10-06 22:02+0900\n"
 "Last-Translator: SZERVÁC Attila <sas@321.hu>\n"
 "Language-Team: Hungarian <translation-team-hu@lists.sourceforge.net>\n"
@@ -260,7 +260,7 @@ msgid "Failed to create symbolic `%s'"
 msgstr "Nem hozható létre e szimlink: %s"
 
 #. setup application name
-#: ../thunar/main.c:47 ../thunar/thunar-window.c:351
+#: ../thunar/main.c:47 ../thunar/thunar-window.c:359
 msgid "Thunar"
 msgstr "Thunar"
 
@@ -729,12 +729,12 @@ msgid "Number of visible files"
 msgstr "Látható fájlok száma"
 
 #: ../thunar/thunar-list-model.c:297 ../thunar/thunar-view.c:111
-#: ../thunar/thunar-window.c:222
+#: ../thunar/thunar-window.c:226
 msgid "Show hidden"
 msgstr "Rejtettek mutatása"
 
 #: ../thunar/thunar-list-model.c:298 ../thunar/thunar-view.c:112
-#: ../thunar/thunar-window.c:223
+#: ../thunar/thunar-window.c:227
 msgid "Whether to display hidden files"
 msgstr "Mutassuk-e a rejtett fájlokat"
 
@@ -794,7 +794,7 @@ msgstr "Hely megnyitása"
 msgid "_Location:"
 msgstr "_Hely:"
 
-#: ../thunar/thunar-navigator.c:137 ../thunar/thunar-window.c:209
+#: ../thunar/thunar-navigator.c:137 ../thunar/thunar-window.c:213
 msgid "Current directory"
 msgstr "Jelenlegi könyvtár"
 
@@ -825,6 +825,68 @@ msgstr "A most megjelenített fájl"
 msgid "The icon size for the path entry"
 msgstr "Az ösvényelem ikonmérete"
 
+#: ../thunar/thunar-preferences-dialog.c:145
+#, fuzzy
+msgid "File Manager Preferences"
+msgstr "Fájlkezelő"
+
+#: ../thunar/thunar-preferences-dialog.c:161
+msgid "<b>Default View</b>"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:172
+msgid "View _new folders using:"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:177
+#, fuzzy
+msgid "Icon View"
+msgstr "Ikonnézet"
+
+#: ../thunar/thunar-preferences-dialog.c:178
+#, fuzzy
+msgid "Detailed List View"
+msgstr "Részletes nézet"
+
+#: ../thunar/thunar-preferences-dialog.c:179
+msgid "Last Active View"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:194
+msgid "Sort _folders before files"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:196
+msgid "Select this option to list folders before files when you sort a folder."
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:200
+#, fuzzy
+msgid "Show hidden and _backup files"
+msgstr "Rejtett fájlok mutatása"
+
+#: ../thunar/thunar-preferences-dialog.c:202
+msgid ""
+"Select this option to show hidden and backup files in new windows. The first "
+"character in a hidden filename is a period (.). The last character in a "
+"backup filename is a tilde (~)."
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:212
+#, fuzzy
+msgid "<b>Icon View</b>"
+msgstr "Ikonnézet"
+
+#: ../thunar/thunar-preferences-dialog.c:223
+msgid "_Text beside icons"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:225
+msgid ""
+"Select this option to place the icon captions for items beside the icon "
+"rather than below the icon."
+msgstr ""
+
 #: ../thunar/thunar-preferences.c:223
 #, fuzzy, c-format
 msgid "Failed to create the Thunar configuration directory in %s"
@@ -1194,7 +1256,7 @@ msgstr ""
 msgid "Text to be displayed in the statusbar associated with this view"
 msgstr "E nézet állapotsorának szövege"
 
-#: ../thunar/thunar-view.c:125 ../thunar/thunar-window.c:237
+#: ../thunar/thunar-view.c:125 ../thunar/thunar-window.c:241
 msgid "UI manager"
 msgstr "UI kezelő"
 
@@ -1202,164 +1264,187 @@ msgstr "UI kezelő"
 msgid "UI manager of the surrounding window"
 msgstr "Adot ablak felhasználói felület kezelője"
 
-#: ../thunar/thunar-window.c:152
+#: ../thunar/thunar-window.c:156
 msgid "_File"
 msgstr "_Fájl"
 
-#: ../thunar/thunar-window.c:153
+#: ../thunar/thunar-window.c:157
 msgid "Open New _Window"
 msgstr "Új _Ablak"
 
-#: ../thunar/thunar-window.c:153
+#: ../thunar/thunar-window.c:157
 msgid "Open a new Thunar window for the displayed location"
 msgstr "Új Thunar ablak az adott helyhez"
 
-#: ../thunar/thunar-window.c:154
+#: ../thunar/thunar-window.c:158
 msgid "Close _All Windows"
 msgstr "_Minden ablak bezárása"
 
-#: ../thunar/thunar-window.c:154
+#: ../thunar/thunar-window.c:158
 msgid "Close all Thunar windows"
 msgstr "Bezár minden Thunar ablakot"
 
-#: ../thunar/thunar-window.c:155
+#: ../thunar/thunar-window.c:159
 msgid "_Close"
 msgstr "_Bezárás"
 
-#: ../thunar/thunar-window.c:155
+#: ../thunar/thunar-window.c:159
 msgid "Close this window"
 msgstr "Bezárja ezt az ablakot"
 
-#: ../thunar/thunar-window.c:156
+#: ../thunar/thunar-window.c:160
 msgid "_Edit"
 msgstr "Sz_erkesztés"
 
-#: ../thunar/thunar-window.c:157
+#: ../thunar/thunar-window.c:161
 #, fuzzy
 msgid "_Preferences"
 msgstr "Tulajdonságok"
 
-#: ../thunar/thunar-window.c:157
+#: ../thunar/thunar-window.c:161
 msgid "Edit Thunar Preferences"
 msgstr ""
 
-#: ../thunar/thunar-window.c:158
+#: ../thunar/thunar-window.c:162
 msgid "_View"
 msgstr "_Nézet"
 
-#: ../thunar/thunar-window.c:159
-msgid "_Location Bar"
+#: ../thunar/thunar-window.c:163
+#, fuzzy
+msgid "_Location Selector"
 msgstr "_Címsor"
 
-#: ../thunar/thunar-window.c:160
+#: ../thunar/thunar-window.c:164
 msgid "_Side Pane"
 msgstr ""
 
-#: ../thunar/thunar-window.c:161
+#: ../thunar/thunar-window.c:165
 msgid "_Go"
 msgstr "_Ugrás"
 
-#: ../thunar/thunar-window.c:162
+#: ../thunar/thunar-window.c:166
 msgid "Open _Parent"
 msgstr "_Szülő megnyitása"
 
-#: ../thunar/thunar-window.c:162
+#: ../thunar/thunar-window.c:166
 msgid "Open the parent folder"
 msgstr "Szülőmappa megnyitása"
 
-#: ../thunar/thunar-window.c:163
+#: ../thunar/thunar-window.c:167
 #, fuzzy
 msgid "_Home"
 msgstr "Saját könyvtár"
 
-#: ../thunar/thunar-window.c:163
+#: ../thunar/thunar-window.c:167
 #, fuzzy
 msgid "Open the home folder"
 msgstr "Szülőmappa megnyitása"
 
-#: ../thunar/thunar-window.c:164
+#: ../thunar/thunar-window.c:168
 msgid "Open _Location..."
 msgstr "_Hely megnyitása..."
 
-#: ../thunar/thunar-window.c:164
+#: ../thunar/thunar-window.c:168
 msgid "Specify a location to open"
 msgstr "Adott hely megnyitása"
 
-#: ../thunar/thunar-window.c:165
+#: ../thunar/thunar-window.c:169
 msgid "_Help"
 msgstr "_Súgó"
 
-#: ../thunar/thunar-window.c:167 ../thunar/thunar-window.c:169
+#: ../thunar/thunar-window.c:171 ../thunar/thunar-window.c:173
 msgid "_About"
 msgstr "_Névjegy"
 
-#: ../thunar/thunar-window.c:167 ../thunar/thunar-window.c:169
+#: ../thunar/thunar-window.c:171 ../thunar/thunar-window.c:173
 msgid "Display information about Thunar"
 msgstr "A Thunar adatainak megjelenítése"
 
-#: ../thunar/thunar-window.c:175
+#: ../thunar/thunar-window.c:179
 #, fuzzy
 msgid "Show _Hidden Files"
 msgstr "Rejtett fájlok mutatása"
 
-#: ../thunar/thunar-window.c:175
+#: ../thunar/thunar-window.c:179
 msgid "Toggles the display of hidden files in the current window"
 msgstr "A rejtett fájlok mutatását váltja a jelen ablakban"
 
-#: ../thunar/thunar-window.c:210
+#: ../thunar/thunar-window.c:214
 msgid "The directory currently displayed within this window"
 msgstr "Ezen ablakban megjelenített könyvtár"
 
-#: ../thunar/thunar-window.c:238
+#: ../thunar/thunar-window.c:242
 msgid "The UI manager used within this window"
 msgstr "Ezen ablakban használt UI kezelő"
 
 #.
 #. * add the side pane options
 #.
-#: ../thunar/thunar-window.c:293
+#: ../thunar/thunar-window.c:297
 msgid "_Favourites"
 msgstr ""
 
-#: ../thunar/thunar-window.c:299 ../thunar/thunar-window.c:320
+#: ../thunar/thunar-window.c:303 ../thunar/thunar-window.c:326
 msgid "_Hidden"
 msgstr "_Rejtett"
 
 #.
-#. * add the location bar options
+#. * add the location selector options
 #.
-#: ../thunar/thunar-window.c:308
-msgid "_Button Style"
-msgstr "_Gomb stílus"
+#: ../thunar/thunar-window.c:312
+#, fuzzy
+msgid "_Pathbar Style"
+msgstr "_Hagyományos stílus"
+
+#: ../thunar/thunar-window.c:313
+msgid "Modern approach with buttons that correspond to folders"
+msgstr ""
 
-#: ../thunar/thunar-window.c:314
-msgid "_Traditional Style"
+#: ../thunar/thunar-window.c:319
+#, fuzzy
+msgid "_Toolbar Style"
 msgstr "_Hagyományos stílus"
 
+#: ../thunar/thunar-window.c:320
+msgid "Traditional approach with location bar and navigation buttons"
+msgstr ""
+
+#: ../thunar/thunar-window.c:326
+msgid "Don't display any location selector"
+msgstr ""
+
 #.
 #. * add view options
 #.
-#: ../thunar/thunar-window.c:329
+#: ../thunar/thunar-window.c:335
 msgid "View as _Icons"
 msgstr ""
 
 #: ../thunar/thunar-window.c:335
+msgid "Display folder content in an icon view"
+msgstr ""
+
+#: ../thunar/thunar-window.c:342
 msgid "View as _Detailed List"
 msgstr ""
 
+#: ../thunar/thunar-window.c:342
+msgid "Display folder content in a detailed list view"
+msgstr ""
+
 #. display an error to the user
-#: ../thunar/thunar-window.c:766
+#: ../thunar/thunar-window.c:836
 #, fuzzy
 msgid "Failed to open home directory"
 msgstr "Nem megnyitható könyvtár: %s"
 
-#: ../thunar/thunar-window.c:843
+#: ../thunar/thunar-window.c:911
 msgid ""
 "Thunar is a fast and easy to use file manager\n"
 "for the Xfce Desktop Environment."
 msgstr ""
 
-#: ../thunar/thunar-window.c:848
+#: ../thunar/thunar-window.c:916
 msgid "translator-credits"
 msgstr ""
 
@@ -1392,6 +1477,9 @@ msgstr "Fájlkezelő"
 msgid "Thunar File Manager"
 msgstr "Fájlkezelő"
 
+#~ msgid "_Button Style"
+#~ msgstr "_Gomb stílus"
+
 #, fuzzy
 #~ msgid "Select by _Pattern"
 #~ msgstr "Kijelölés mintával"
diff --git a/po/ja.po b/po/ja.po
index 951c31028..8af6b7f5c 100644
--- a/po/ja.po
+++ b/po/ja.po
@@ -9,7 +9,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: Thunar 0.1.2svn\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2005-11-15 19:36+0100\n"
+"POT-Creation-Date: 2005-11-15 22:36+0100\n"
 "PO-Revision-Date: 2005-10-06 21:58+0900\n"
 "Last-Translator: Daichi Kawahata <daichi@xfce.org>\n"
 "Language-Team: Japanese <xfce-users-jp@ml.fdiary.net>\n"
@@ -262,7 +262,7 @@ msgid "Failed to create symbolic `%s'"
 msgstr "リンク %s を作成できません。"
 
 #. setup application name
-#: ../thunar/main.c:47 ../thunar/thunar-window.c:351
+#: ../thunar/main.c:47 ../thunar/thunar-window.c:359
 msgid "Thunar"
 msgstr "Thunar"
 
@@ -718,12 +718,12 @@ msgid "Number of visible files"
 msgstr "表示されるファイルの数です"
 
 #: ../thunar/thunar-list-model.c:297 ../thunar/thunar-view.c:111
-#: ../thunar/thunar-window.c:222
+#: ../thunar/thunar-window.c:226
 msgid "Show hidden"
 msgstr "隠しファイルを表示"
 
 #: ../thunar/thunar-list-model.c:298 ../thunar/thunar-view.c:112
-#: ../thunar/thunar-window.c:223
+#: ../thunar/thunar-window.c:227
 msgid "Whether to display hidden files"
 msgstr "隠しファイルを表示します"
 
@@ -780,7 +780,7 @@ msgstr "場所を開きます"
 msgid "_Location:"
 msgstr "場所(_L):"
 
-#: ../thunar/thunar-navigator.c:137 ../thunar/thunar-window.c:209
+#: ../thunar/thunar-navigator.c:137 ../thunar/thunar-window.c:213
 msgid "Current directory"
 msgstr "現在のフォルダ"
 
@@ -810,6 +810,68 @@ msgstr "現在表示されているファイルです"
 msgid "The icon size for the path entry"
 msgstr "パス・エントリーのアイコン・サイズです"
 
+#: ../thunar/thunar-preferences-dialog.c:145
+#, fuzzy
+msgid "File Manager Preferences"
+msgstr "ファイルマネージャー"
+
+#: ../thunar/thunar-preferences-dialog.c:161
+msgid "<b>Default View</b>"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:172
+msgid "View _new folders using:"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:177
+#, fuzzy
+msgid "Icon View"
+msgstr "アイコン表示"
+
+#: ../thunar/thunar-preferences-dialog.c:178
+#, fuzzy
+msgid "Detailed List View"
+msgstr "詳細表示"
+
+#: ../thunar/thunar-preferences-dialog.c:179
+msgid "Last Active View"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:194
+msgid "Sort _folders before files"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:196
+msgid "Select this option to list folders before files when you sort a folder."
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:200
+#, fuzzy
+msgid "Show hidden and _backup files"
+msgstr "隠しファイルを表示(_H)"
+
+#: ../thunar/thunar-preferences-dialog.c:202
+msgid ""
+"Select this option to show hidden and backup files in new windows. The first "
+"character in a hidden filename is a period (.). The last character in a "
+"backup filename is a tilde (~)."
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:212
+#, fuzzy
+msgid "<b>Icon View</b>"
+msgstr "アイコン表示"
+
+#: ../thunar/thunar-preferences-dialog.c:223
+msgid "_Text beside icons"
+msgstr ""
+
+#: ../thunar/thunar-preferences-dialog.c:225
+msgid ""
+"Select this option to place the icon captions for items beside the icon "
+"rather than below the icon."
+msgstr ""
+
 #: ../thunar/thunar-preferences.c:223
 #, fuzzy, c-format
 msgid "Failed to create the Thunar configuration directory in %s"
@@ -1172,7 +1234,7 @@ msgstr "折り返し幅です"
 msgid "Text to be displayed in the statusbar associated with this view"
 msgstr "この表示に関連付けられたステータスバーで表示されるテキストです"
 
-#: ../thunar/thunar-view.c:125 ../thunar/thunar-window.c:237
+#: ../thunar/thunar-view.c:125 ../thunar/thunar-window.c:241
 msgid "UI manager"
 msgstr "UI マネージャ"
 
@@ -1180,158 +1242,181 @@ msgstr "UI マネージャ"
 msgid "UI manager of the surrounding window"
 msgstr "ウィンドウを囲う UI マネージャです"
 
-#: ../thunar/thunar-window.c:152
+#: ../thunar/thunar-window.c:156
 msgid "_File"
 msgstr "ファイル(_F)"
 
-#: ../thunar/thunar-window.c:153
+#: ../thunar/thunar-window.c:157
 msgid "Open New _Window"
 msgstr "新しいウィンドウを開く(_W)"
 
-#: ../thunar/thunar-window.c:153
+#: ../thunar/thunar-window.c:157
 msgid "Open a new Thunar window for the displayed location"
 msgstr "表示されている場所の Thunar ウィンドウを新しく開きます"
 
-#: ../thunar/thunar-window.c:154
+#: ../thunar/thunar-window.c:158
 msgid "Close _All Windows"
 msgstr "全ウィンドウを閉じる(_A)"
 
-#: ../thunar/thunar-window.c:154
+#: ../thunar/thunar-window.c:158
 msgid "Close all Thunar windows"
 msgstr "Thunar の全てのウィンドウを閉じます"
 
-#: ../thunar/thunar-window.c:155
+#: ../thunar/thunar-window.c:159
 msgid "_Close"
 msgstr "閉じる(_C)"
 
-#: ../thunar/thunar-window.c:155
+#: ../thunar/thunar-window.c:159
 msgid "Close this window"
 msgstr "このウィンドウを閉じます"
 
-#: ../thunar/thunar-window.c:156
+#: ../thunar/thunar-window.c:160
 msgid "_Edit"
 msgstr "編集(_E)"
 
-#: ../thunar/thunar-window.c:157
+#: ../thunar/thunar-window.c:161
 #, fuzzy
 msgid "_Preferences"
 msgstr "プロパティ(_P)"
 
-#: ../thunar/thunar-window.c:157
+#: ../thunar/thunar-window.c:161
 msgid "Edit Thunar Preferences"
 msgstr ""
 
-#: ../thunar/thunar-window.c:158
+#: ../thunar/thunar-window.c:162
 msgid "_View"
 msgstr "表示(_V)"
 
-#: ../thunar/thunar-window.c:159
-msgid "_Location Bar"
+#: ../thunar/thunar-window.c:163
+#, fuzzy
+msgid "_Location Selector"
 msgstr "場所バー(_L)"
 
-#: ../thunar/thunar-window.c:160
+#: ../thunar/thunar-window.c:164
 msgid "_Side Pane"
 msgstr "サイドペイン(_S)"
 
-#: ../thunar/thunar-window.c:161
+#: ../thunar/thunar-window.c:165
 msgid "_Go"
 msgstr "移動(_G)"
 
-#: ../thunar/thunar-window.c:162
+#: ../thunar/thunar-window.c:166
 msgid "Open _Parent"
 msgstr "親フォルダを開く(_P)"
 
-#: ../thunar/thunar-window.c:162
+#: ../thunar/thunar-window.c:166
 msgid "Open the parent folder"
 msgstr "親フォルダを開きます"
 
-#: ../thunar/thunar-window.c:163
+#: ../thunar/thunar-window.c:167
 #, fuzzy
 msgid "_Home"
 msgstr "ホーム"
 
-#: ../thunar/thunar-window.c:163
+#: ../thunar/thunar-window.c:167
 #, fuzzy
 msgid "Open the home folder"
 msgstr "親フォルダを開きます"
 
-#: ../thunar/thunar-window.c:164
+#: ../thunar/thunar-window.c:168
 msgid "Open _Location..."
 msgstr "場所を開く(_L)..."
 
-#: ../thunar/thunar-window.c:164
+#: ../thunar/thunar-window.c:168
 msgid "Specify a location to open"
 msgstr "開く場所を指定します"
 
-#: ../thunar/thunar-window.c:165
+#: ../thunar/thunar-window.c:169
 msgid "_Help"
 msgstr "ヘルプ(_H)"
 
-#: ../thunar/thunar-window.c:167 ../thunar/thunar-window.c:169
+#: ../thunar/thunar-window.c:171 ../thunar/thunar-window.c:173
 msgid "_About"
 msgstr "このプログラムについて(_A)"
 
-#: ../thunar/thunar-window.c:167 ../thunar/thunar-window.c:169
+#: ../thunar/thunar-window.c:171 ../thunar/thunar-window.c:173
 msgid "Display information about Thunar"
 msgstr "Thunar についての情報を表示します"
 
-#: ../thunar/thunar-window.c:175
+#: ../thunar/thunar-window.c:179
 #, fuzzy
 msgid "Show _Hidden Files"
 msgstr "隠しファイルを表示(_H)"
 
-#: ../thunar/thunar-window.c:175
+#: ../thunar/thunar-window.c:179
 msgid "Toggles the display of hidden files in the current window"
 msgstr "現在のウィンドウで隠しファイルの表示/非表示を切り替えます"
 
-#: ../thunar/thunar-window.c:210
+#: ../thunar/thunar-window.c:214
 msgid "The directory currently displayed within this window"
 msgstr "現在このウィンドウ内に表示されているフォルダです"
 
-#: ../thunar/thunar-window.c:238
+#: ../thunar/thunar-window.c:242
 msgid "The UI manager used within this window"
 msgstr "このウィンドウ内で使用されている UI マネージャです"
 
 #.
 #. * add the side pane options
 #.
-#: ../thunar/thunar-window.c:293
+#: ../thunar/thunar-window.c:297
 msgid "_Favourites"
 msgstr "お気に入り(_F)"
 
-#: ../thunar/thunar-window.c:299 ../thunar/thunar-window.c:320
+#: ../thunar/thunar-window.c:303 ../thunar/thunar-window.c:326
 msgid "_Hidden"
 msgstr "隠す(_H)"
 
 #.
-#. * add the location bar options
+#. * add the location selector options
 #.
-#: ../thunar/thunar-window.c:308
-msgid "_Button Style"
-msgstr "ボタン式(_B)"
+#: ../thunar/thunar-window.c:312
+#, fuzzy
+msgid "_Pathbar Style"
+msgstr "旧式(_T)"
+
+#: ../thunar/thunar-window.c:313
+msgid "Modern approach with buttons that correspond to folders"
+msgstr ""
 
-#: ../thunar/thunar-window.c:314
-msgid "_Traditional Style"
+#: ../thunar/thunar-window.c:319
+#, fuzzy
+msgid "_Toolbar Style"
 msgstr "旧式(_T)"
 
+#: ../thunar/thunar-window.c:320
+msgid "Traditional approach with location bar and navigation buttons"
+msgstr ""
+
+#: ../thunar/thunar-window.c:326
+msgid "Don't display any location selector"
+msgstr ""
+
 #.
 #. * add view options
 #.
-#: ../thunar/thunar-window.c:329
+#: ../thunar/thunar-window.c:335
 msgid "View as _Icons"
 msgstr "アイコン表示(_I)"
 
 #: ../thunar/thunar-window.c:335
+msgid "Display folder content in an icon view"
+msgstr ""
+
+#: ../thunar/thunar-window.c:342
 msgid "View as _Detailed List"
 msgstr "詳細リスト表示(_D)"
 
+#: ../thunar/thunar-window.c:342
+msgid "Display folder content in a detailed list view"
+msgstr ""
+
 #. display an error to the user
-#: ../thunar/thunar-window.c:766
+#: ../thunar/thunar-window.c:836
 #, fuzzy
 msgid "Failed to open home directory"
 msgstr "フォルダ %s を開けません。"
 
-#: ../thunar/thunar-window.c:843
+#: ../thunar/thunar-window.c:911
 msgid ""
 "Thunar is a fast and easy to use file manager\n"
 "for the Xfce Desktop Environment."
@@ -1339,7 +1424,7 @@ msgstr ""
 "Thunar は Xfce デスクトップ環境向けの\n"
 "使いやすい軽快なファイルマネージャーです"
 
-#: ../thunar/thunar-window.c:848
+#: ../thunar/thunar-window.c:916
 msgid "translator-credits"
 msgstr "Daichi Kawahata <daichi@xfce.org>"
 
@@ -1371,6 +1456,9 @@ msgstr "ファイルマネージャー"
 msgid "Thunar File Manager"
 msgstr "Thunar ファイルマネージャー"
 
+#~ msgid "_Button Style"
+#~ msgstr "ボタン式(_B)"
+
 #, fuzzy
 #~ msgid "Select by _Pattern"
 #~ msgstr "パターンで選択(_P)"
diff --git a/thunar/thunar-gtk-extensions.c b/thunar/thunar-gtk-extensions.c
index 03196e8d7..654c325cb 100644
--- a/thunar/thunar-gtk-extensions.c
+++ b/thunar/thunar-gtk-extensions.c
@@ -25,6 +25,34 @@
 
 
 
+/**
+ * thunar_gtk_action_group_create_tool_item:
+ * @action_group : a #GtkActionGroup.
+ * @action_name  : the name of a #GtkAction in @action_group.
+ *
+ * Convenience function to create a #GtkToolItem for the #GtkAction
+ * named @action_name in @action_group.
+ *
+ * Return value: the #GtkToolItem for @action_name in @action_group.
+ **/
+GtkToolItem*
+thunar_gtk_action_group_create_tool_item (GtkActionGroup *action_group,
+                                          const gchar    *action_name)
+{
+  GtkAction *action;
+
+  g_return_val_if_fail (GTK_IS_ACTION_GROUP (action_group), NULL);
+  g_return_val_if_fail (action_name != NULL, NULL);
+
+  action = gtk_action_group_get_action (action_group, action_name);
+  if (G_UNLIKELY (action == NULL))
+    return NULL;
+
+  return GTK_TOOL_ITEM (gtk_action_create_tool_item (action));
+}
+
+
+
 /**
  * thunar_gtk_action_group_set_action_sensitive:
  * @action_group : a #GtkActionGroup.
diff --git a/thunar/thunar-gtk-extensions.h b/thunar/thunar-gtk-extensions.h
index 078e94e12..baecbb918 100644
--- a/thunar/thunar-gtk-extensions.h
+++ b/thunar/thunar-gtk-extensions.h
@@ -24,9 +24,11 @@
 
 G_BEGIN_DECLS;
 
-void thunar_gtk_action_group_set_action_sensitive (GtkActionGroup *action_group,
-                                                   const gchar    *action_name,
-                                                   gboolean        sensitive);
+GtkToolItem *thunar_gtk_action_group_create_tool_item     (GtkActionGroup *action_group,
+                                                           const gchar    *action_name) G_GNUC_INTERNAL G_GNUC_MALLOC;
+void         thunar_gtk_action_group_set_action_sensitive (GtkActionGroup *action_group,
+                                                           const gchar    *action_name,
+                                                           gboolean        sensitive) G_GNUC_INTERNAL;
 
 G_END_DECLS;
 
diff --git a/thunar/thunar-location-bar.c b/thunar/thunar-location-bar.c
index c2b0777a7..a2b602fea 100644
--- a/thunar/thunar-location-bar.c
+++ b/thunar/thunar-location-bar.c
@@ -83,3 +83,23 @@ thunar_location_bar_accept_focus (ThunarLocationBar *location_bar)
   return (*THUNAR_LOCATION_BAR_GET_IFACE (location_bar)->accept_focus) (location_bar);
 }
 
+
+
+/**
+ * thunar_location_bar_is_standalone:
+ * @location_bar : a #ThunarLocationBar.
+ *
+ * Returns %TRUE if @location_bar should not be placed in the location
+ * toolbar, but should be treated as a standalone component, which is
+ * placed near to the view pane. Else, if %FALSE is returned, the
+ * @location_bar will be placed into the location toolbar.
+ *
+ * Return value: %FALSE to embed @location_bar into the location toolbar,
+ *               %TRUE to treat it as a standalone component.
+ **/
+gboolean
+thunar_location_bar_is_standalone (ThunarLocationBar *location_bar)
+{
+  g_return_val_if_fail (THUNAR_IS_LOCATION_BAR (location_bar), FALSE);
+  return (*THUNAR_LOCATION_BAR_GET_IFACE (location_bar)->is_standalone) (location_bar);
+}
diff --git a/thunar/thunar-location-bar.h b/thunar/thunar-location-bar.h
index 0737bd46e..3a8db754f 100644
--- a/thunar/thunar-location-bar.h
+++ b/thunar/thunar-location-bar.h
@@ -37,12 +37,14 @@ struct _ThunarLocationBarIface
   GTypeInterface __parent__;
 
   /* virtual methods */
-  gboolean (*accept_focus) (ThunarLocationBar *location_bar);
+  gboolean (*accept_focus)  (ThunarLocationBar *location_bar);
+  gboolean (*is_standalone) (ThunarLocationBar *location_bar);
 };
 
 GType    thunar_location_bar_get_type     (void) G_GNUC_CONST;
 
-gboolean thunar_location_bar_accept_focus (ThunarLocationBar *location_bar);
+gboolean thunar_location_bar_accept_focus  (ThunarLocationBar *location_bar);
+gboolean thunar_location_bar_is_standalone (ThunarLocationBar *location_bar);
 
 G_END_DECLS;
 
diff --git a/thunar/thunar-location-buttons.c b/thunar/thunar-location-buttons.c
index ff41cd300..c1979d6d8 100644
--- a/thunar/thunar-location-buttons.c
+++ b/thunar/thunar-location-buttons.c
@@ -232,6 +232,7 @@ static void
 thunar_location_buttons_location_bar_init (ThunarLocationBarIface *iface)
 {
   iface->accept_focus = thunar_location_buttons_accept_focus;
+  iface->is_standalone = (gpointer) exo_noop_true;
 }
 
 
diff --git a/thunar/thunar-location-entry.c b/thunar/thunar-location-entry.c
index 9dfd969af..9b068fcf1 100644
--- a/thunar/thunar-location-entry.c
+++ b/thunar/thunar-location-entry.c
@@ -110,6 +110,7 @@ static void
 thunar_location_entry_location_bar_init (ThunarLocationBarIface *iface)
 {
   iface->accept_focus = thunar_location_entry_accept_focus;
+  iface->is_standalone = (gpointer) exo_noop_false;
 }
 
 
diff --git a/thunar/thunar-window-ui.xml b/thunar/thunar-window-ui.xml
index dcc81bac7..56fd5c756 100644
--- a/thunar/thunar-window-ui.xml
+++ b/thunar/thunar-window-ui.xml
@@ -34,10 +34,10 @@
     </menu>
 
     <menu action="view-menu" name="view-menu">
-      <menu action="view-location-bar-menu" name="view-location-bar-menu">
-        <menuitem action="view-location-bar-buttons" name="view-location-bar-buttons" />
-        <menuitem action="view-location-bar-entry" name="view-location-bar-entry" />
-        <menuitem action="view-location-bar-hidden" name="view-location-bar-hidden" />
+      <menu action="view-location-selector-menu" name="view-location-selector-menu">
+        <menuitem action="view-location-selector-pathbar" name="view-location-selector-pathbar" />
+        <menuitem action="view-location-selector-toolbar" name="view-location-selector-toolbar" />
+        <menuitem action="view-location-selector-hidden" name="view-location-selector-hidden" />
       </menu>
       <menu action="view-side-pane-menu" name="view-side-pane-menu">
         <menuitem action="view-side-pane-favourites" name="view-side-pane-favourites" />
diff --git a/thunar/thunar-window.c b/thunar/thunar-window.c
index f81f3f631..aa887425f 100644
--- a/thunar/thunar-window.c
+++ b/thunar/thunar-window.c
@@ -135,11 +135,15 @@ struct _ThunarWindow
   guint                   menu_item_tooltip_id;
 
   GtkWidget              *paned;
-  GtkWidget              *location_bar;
   GtkWidget              *view_container;
   GtkWidget              *view;
   GtkWidget              *statusbar;
 
+  /* support for two different styles of location bars (standalone/toolbar'ed) */
+  GtkWidget              *location_standalone_box;
+  GtkWidget              *location_toolbar_box;
+  GtkWidget              *location_bar;
+
   ThunarHistory          *history;
 
   ThunarFile             *current_directory;
@@ -156,7 +160,7 @@ static const GtkActionEntry action_entries[] =
   { "edit-menu", NULL, N_ ("_Edit"), NULL, },
   { "preferences", GTK_STOCK_PREFERENCES, N_ ("_Preferences"), NULL, N_ ("Edit Thunar Preferences"), G_CALLBACK (thunar_window_action_preferences), },
   { "view-menu", NULL, N_ ("_View"), NULL, },
-  { "view-location-bar-menu", NULL, N_ ("_Location Bar"), NULL, },
+  { "view-location-selector-menu", NULL, N_ ("_Location Selector"), NULL, },
   { "view-side-pane-menu", NULL, N_ ("_Side Pane"), NULL, },
   { "go-menu", NULL, N_ ("_Go"), NULL, },
   { "open-parent", GTK_STOCK_GO_UP, N_ ("Open _Parent"), "<alt>Up", N_ ("Open the parent folder"), G_CALLBACK (thunar_window_action_go_up), },
@@ -303,21 +307,23 @@ thunar_window_init (ThunarWindow *window)
   g_object_unref (G_OBJECT (radio_action));
 
   /*
    * add the location bar options
    */
-  radio_action = gtk_radio_action_new ("view-location-bar-buttons", _("_Button Style"), NULL, NULL, THUNAR_TYPE_LOCATION_BUTTONS);
+  radio_action = gtk_radio_action_new ("view-location-selector-pathbar", _("_Pathbar Style"),
+                                       _("Modern approach with buttons that correspond to folders"), NULL, THUNAR_TYPE_LOCATION_BUTTONS);
   gtk_action_group_add_action (window->action_group, GTK_ACTION (radio_action));
   gtk_radio_action_set_group (radio_action, NULL);
   group = gtk_radio_action_get_group (radio_action);
   g_object_unref (G_OBJECT (radio_action));
 
-  radio_action = gtk_radio_action_new ("view-location-bar-entry", _("_Traditional Style"), NULL, NULL, THUNAR_TYPE_LOCATION_ENTRY);
+  radio_action = gtk_radio_action_new ("view-location-selector-toolbar", _("_Toolbar Style"),
+                                       _("Traditional approach with location bar and navigation buttons"), NULL, THUNAR_TYPE_LOCATION_ENTRY);
   gtk_action_group_add_action (window->action_group, GTK_ACTION (radio_action));
   gtk_radio_action_set_group (radio_action, group);
   group = gtk_radio_action_get_group (radio_action);
   g_object_unref (G_OBJECT (radio_action));
 
-  radio_action = gtk_radio_action_new ("view-location-bar-hidden", _("_Hidden"), NULL, NULL, G_TYPE_NONE);
+  radio_action = gtk_radio_action_new ("view-location-selector-hidden", _("_Hidden"), _("Don't display any location selector"), NULL, G_TYPE_NONE);
   gtk_action_group_add_action (window->action_group, GTK_ACTION (radio_action));
   gtk_radio_action_set_group (radio_action, group);
   group = gtk_radio_action_get_group (radio_action);
@@ -326,13 +332,15 @@ thunar_window_init (ThunarWindow *window)
   /*
    * add view options
    */
-  radio_action = gtk_radio_action_new ("view-as-icons", _("View as _Icons"), NULL, NULL, THUNAR_TYPE_ICON_VIEW);
+  radio_action = gtk_radio_action_new ("view-as-icons", _("View as _Icons"), _("Display folder content in an icon view"),
+                                       NULL, THUNAR_TYPE_ICON_VIEW);
   gtk_action_group_add_action (window->action_group, GTK_ACTION (radio_action));
   gtk_radio_action_set_group (radio_action, NULL);
   group = gtk_radio_action_get_group (radio_action);
   g_object_unref (G_OBJECT (radio_action));
 
-  radio_action = gtk_radio_action_new ("view-as-detailed-list", _("View as _Detailed List"), NULL, NULL, THUNAR_TYPE_DETAILS_VIEW);
+  radio_action = gtk_radio_action_new ("view-as-detailed-list", _("View as _Detailed List"), _("Display folder content in a detailed list view"),
+                                       NULL, THUNAR_TYPE_DETAILS_VIEW);
   gtk_action_group_add_action (window->action_group, GTK_ACTION (radio_action));
   gtk_radio_action_set_group (radio_action, group);
   group = gtk_radio_action_get_group (radio_action);
@@ -358,6 +366,10 @@ thunar_window_init (ThunarWindow *window)
   gtk_box_pack_start (GTK_BOX (vbox), menubar, FALSE, FALSE, 0);
   gtk_widget_show (menubar);
 
+  window->location_toolbar_box = gtk_alignment_new (0.0f, 0.5f, 1.0f, 1.0f);
+  gtk_box_pack_start (GTK_BOX (vbox), window->location_toolbar_box, FALSE, FALSE, 0);
+  gtk_widget_show (window->location_toolbar_box);
+
   window->paned = g_object_new (GTK_TYPE_HPANED, "border-width", 6, NULL);
   gtk_box_pack_start (GTK_BOX (vbox), window->paned, TRUE, TRUE, 0);
   gtk_widget_show (window->paned);
@@ -366,9 +378,9 @@ thunar_window_init (ThunarWindow *window)
   gtk_paned_pack2 (GTK_PANED (window->paned), box, TRUE, FALSE);
   gtk_widget_show (box);
 
-  window->location_bar = gtk_alignment_new (0.0f, 0.5f, 1.0f, 1.0f);
-  gtk_box_pack_start (GTK_BOX (box), window->location_bar, FALSE, FALSE, 0);
-  gtk_widget_show (window->location_bar);
+  window->location_standalone_box = gtk_alignment_new (0.0f, 0.5f, 1.0f, 1.0f);
+  gtk_box_pack_start (GTK_BOX (box), window->location_standalone_box, FALSE, FALSE, 0);
+  gtk_widget_show (window->location_standalone_box);
 
   window->view_container = gtk_alignment_new (0.5f, 0.5f, 1.0f, 1.0f);
   gtk_box_pack_start (GTK_BOX (box), window->view_container, TRUE, TRUE, 0);
@@ -401,7 +413,7 @@ thunar_window_init (ThunarWindow *window)
   g_free (type_name);
 
   /* activate the selected location bar */
-  action = gtk_action_group_get_action (window->action_group, "view-location-bar-buttons");
+  action = gtk_action_group_get_action (window->action_group, "view-location-selector-pathbar");
   exo_gtk_radio_action_set_current_value (GTK_RADIO_ACTION (action), g_type_is_a (type, THUNAR_TYPE_LOCATION_BAR) ? type : G_TYPE_NONE);
   g_signal_connect (G_OBJECT (action), "changed", G_CALLBACK (thunar_window_action_location_bar_changed), window);
   thunar_window_action_location_bar_changed (GTK_RADIO_ACTION (action), GTK_RADIO_ACTION (action), window);
@@ -616,13 +628,20 @@ thunar_window_action_location_bar_changed (GtkRadioAction *action,
                                            GtkRadioAction *current,
                                            ThunarWindow   *window)
 {
-  GtkWidget *widget;
-  GType      type;
+  GtkToolItem *toolitem;
+  GtkWidget   *toolbar;
+  GType        type;
 
   /* drop the previous location bar (if any) */
-  widget = gtk_bin_get_child (GTK_BIN (window->location_bar));
-  if (G_LIKELY (widget != NULL))
-    gtk_widget_destroy (widget);
+  if (G_UNLIKELY (window->location_bar != NULL))
+    {
+      gtk_widget_destroy (window->location_bar);
+      window->location_bar = NULL;
+    }
+
+  /* hide the location bar containers */
+  gtk_widget_hide (window->location_standalone_box);
+  gtk_widget_hide (window->location_toolbar_box);
 
   /* determine the new type of location bar */
   type = gtk_radio_action_get_current_value (action);
@@ -631,22 +650,73 @@ thunar_window_action_location_bar_changed (GtkRadioAction *action,
   if (G_LIKELY (type != G_TYPE_NONE))
     {
       /* initialize the new location bar widget */
-      widget = g_object_new (type, NULL);
-      g_signal_connect_swapped (G_OBJECT (widget), "change-directory",
-                                G_CALLBACK (thunar_window_set_current_directory), window);
-      exo_binding_new (G_OBJECT (window), "current-directory",
-                       G_OBJECT (widget), "current-directory");
-      gtk_container_add (GTK_CONTAINER (window->location_bar), widget);
-      gtk_widget_show (widget);
+      window->location_bar = g_object_new (type, NULL);
+      exo_binding_new (G_OBJECT (window), "current-directory", G_OBJECT (window->location_bar), "current-directory");
+      g_signal_connect_swapped (G_OBJECT (window->location_bar), "change-directory", G_CALLBACK (thunar_window_set_current_directory), window);
 
-      /* display the location bar container */
+      /* check if the location bar should be placed into a toolbar */
+      if (!thunar_location_bar_is_standalone (THUNAR_LOCATION_BAR (window->location_bar)))
+        {
+          /* be sure to drop any previous toolbar */
+          toolbar = gtk_bin_get_child (GTK_BIN (window->location_toolbar_box));
+          if (G_LIKELY (toolbar != NULL))
+            gtk_widget_destroy (toolbar);
+
+          /* allocate the new toolbar */
+          toolbar = gtk_toolbar_new ();
+          gtk_container_add (GTK_CONTAINER (window->location_toolbar_box), toolbar);
+          gtk_widget_show (toolbar);
+
+          /* add the "back" action */
+          toolitem = thunar_gtk_action_group_create_tool_item (window->action_group, "back");
+          gtk_toolbar_insert (GTK_TOOLBAR (toolbar), toolitem, -1);
+          gtk_widget_show (GTK_WIDGET (toolitem));
+
+          /* add the "forward" action */
+          toolitem = thunar_gtk_action_group_create_tool_item (window->action_group, "forward");
+          gtk_toolbar_insert (GTK_TOOLBAR (toolbar), toolitem, -1);
+          gtk_widget_show (GTK_WIDGET (toolitem));
+
+          /* add the "open-parent" action */
+          toolitem = thunar_gtk_action_group_create_tool_item (window->action_group, "open-parent");
+          gtk_toolbar_insert (GTK_TOOLBAR (toolbar), toolitem, -1);
+          gtk_widget_show (GTK_WIDGET (toolitem));
+
+          /* add a separator */
+          toolitem = gtk_separator_tool_item_new ();
+          gtk_toolbar_insert (GTK_TOOLBAR (toolbar), toolitem, -1);
+          gtk_widget_show (GTK_WIDGET (toolitem));
+
+          /* add the "open-home" action */
+          toolitem = thunar_gtk_action_group_create_tool_item (window->action_group, "open-home");
+          gtk_toolbar_insert (GTK_TOOLBAR (toolbar), toolitem, -1);
+          gtk_widget_show (GTK_WIDGET (toolitem));
+
+          /* add a separator */
+          toolitem = gtk_separator_tool_item_new ();
+          gtk_toolbar_insert (GTK_TOOLBAR (toolbar), toolitem, -1);
+          gtk_widget_show (GTK_WIDGET (toolitem));
+
+          /* add the toolitem with the location bar */
+          toolitem = gtk_tool_item_new ();
+          gtk_tool_item_set_expand (toolitem, TRUE);
+          gtk_container_add (GTK_CONTAINER (toolitem), window->location_bar);
+          gtk_toolbar_insert (GTK_TOOLBAR (toolbar), toolitem, -1);
+          gtk_widget_show (GTK_WIDGET (toolitem));
+
+          /* make the location toolbar container visible */
+          gtk_widget_show (window->location_toolbar_box);
+        }
+      else
+        {
+          /* it's a standalone location bar, just place it in the standalone container */
+          gtk_container_add (GTK_CONTAINER (window->location_standalone_box), window->location_bar);
+          gtk_widget_show (window->location_standalone_box);
+        }
+
+      /* display the new location bar widget */
       gtk_widget_show (window->location_bar);
     }
-  else
-    {
-      /* hide the location bar container */
-      gtk_widget_hide (window->location_bar);
-    }
 
   /* remember the setting */
   g_object_set (G_OBJECT (window->preferences), "last-location-bar", g_type_name (type), NULL);
@@ -784,13 +854,11 @@ thunar_window_action_open_location (GtkAction    *action,
                                     ThunarWindow *window)
 {
   GtkWidget *dialog;
-  GtkWidget *widget;
 
   /* bring up the "Open Location"-dialog if the window has no location bar or the location bar
    * in the window does not support text entry by the user.
    */
-  widget = gtk_bin_get_child (GTK_BIN (window->location_bar));
-  if (widget == NULL || !thunar_location_bar_accept_focus (THUNAR_LOCATION_BAR (widget)))
+  if (window->location_bar == NULL || !thunar_location_bar_accept_focus (THUNAR_LOCATION_BAR (window->location_bar)))
     {
       dialog = thunar_location_dialog_new ();
       gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
@@ -303,21 +307,23 @@ thunar_window_init (ThunarWindow *window)
 
   /*
-   * add the location bar options
+   * add the location selector options
    */
-- 
GitLab